<?php
namespace Debug\Sample;

    class First {}

}
